@@ -1,12 +1,12 @@
 /*
- * Copyright (C) 2015, 2017 XStream Committers.
+ * Copyright (C) 2015, 2017, 2021 XStream Committers.
  * All rights reserved.
  *
  * The software in this package is published under the terms of the BSD
  * style license a copy of which has been included with this distribution in
  * the LICENSE.txt file.
  *
- * Created on 08.11.2015 by Joerg Schaible
+ * Created on 8. November 2015 by Joerg Schaible
  */
 package com.thoughtworks.xstream.benchmark.jmh;
 
@@ -37,6 +37,7 @@ import com.thoughtworks.xstream.converters.SingleValueConverter;
 import com.thoughtworks.xstream.converters.basic.AbstractSingleValueConverter;
 import com.thoughtworks.xstream.core.util.WeakCache;
 import com.thoughtworks.xstream.io.xml.CompactWriter;
+import com.thoughtworks.xstream.io.xml.MXParserDriver;
 import com.thoughtworks.xstream.io.xml.PrettyPrintWriter;
 import com.thoughtworks.xstream.io.xml.Xpp3Driver;
 import com.thoughtworks.xstream.security.ArrayTypePermission;
@@ -257,7 +258,7 @@ public class StringConverterBenchmark {
         } else {
             throw new IllegalStateException("Unsupported benchmark type: " + benchmark);
         }
-        xstream = new XStream(new Xpp3Driver());
+        xstream = new XStream(new MXParserDriver());
         xstream.addPermission(NoTypePermission.NONE);
         xstream.addPermission(ArrayTypePermission.ARRAYS);
         xstream.allowTypes(new Class[] {String.class});
