@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2006 Joe Walnes.
- * Copyright (C) 2006, 2007, 2008, 2009, 2011, 2013, 2019, 2020 XStream Committers.
+ * Copyright (C) 2006, 2007, 2008, 2009, 2011, 2013, 2019, 2020, 2021 XStream Committers.
  * All rights reserved.
  *
  * The software in this package is published under the terms of the BSD
@@ -495,7 +495,7 @@ public class XmlFriendlyNameCoder implements NameCoder, Cloneable {
 
             for (; i < length; i++) {
                 final char c = name.charAt(i);
-                if (c < 'A' || (c > 'Z' && c < 'a') || c > 'Z') {
+                if (c < 'A' || (c > 'Z' && c < 'a') || c > 'z') {
                     break;
                 }
             }
