@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013, 2014, 2017, 2018, 2020, 2021 XStream Committers.
+ * Copyright (C) 2013, 2014, 2017, 2018, 2020, 2021, 2022 XStream Committers.
  * All rights reserved.
  *
  * The software in this package is published under the terms of the BSD
@@ -293,7 +293,7 @@ public class SecurityVulnerabilityTest extends AbstractAcceptanceTest {
             xstream.fromXML(xml);
             fail("Thrown " + InputManipulationException.class.getName() + " expected");
         } catch (final InputManipulationException e) {
-            assertTrue("Limit expected in message", e.getMessage().contains("exceeds 5 seconds"));
+            assertTrue("Limit expected in message", e.getMessage().indexOf("exceeds 5 seconds") > 0);
         }
     }
 
@@ -320,7 +320,7 @@ public class SecurityVulnerabilityTest extends AbstractAcceptanceTest {
             xstream.fromXML(xml);
             fail("Thrown " + InputManipulationException.class.getName() + " expected");
         } catch (final InputManipulationException e) {
-            assertTrue("Limit expected in message", e.getMessage().contains("exceeds 5 seconds"));
+            assertTrue("Limit expected in message", e.getMessage().indexOf("exceeds 5 seconds") > 0);
         }
     }
 
@@ -347,7 +347,7 @@ public class SecurityVulnerabilityTest extends AbstractAcceptanceTest {
             xstream.fromXML(xml);
             fail("Thrown " + InputManipulationException.class.getName() + " expected");
         } catch (InputManipulationException e) {
-            assertTrue("Limit expected in message", e.getMessage().contains("exceeds 5 seconds"));
+            assertTrue("Limit expected in message", e.getMessage().indexOf("exceeds 5 seconds") >= 0);
         }
     }
 
@@ -374,7 +374,7 @@ public class SecurityVulnerabilityTest extends AbstractAcceptanceTest {
             xstream.fromXML(xml);
             fail("Thrown " + InputManipulationException.class.getName() + " expected");
         } catch (final InputManipulationException e) {
-            assertTrue("Limit expected in message", e.getMessage().contains("exceeds 5 seconds"));
+            assertTrue("Limit expected in message", e.getMessage().indexOf("exceeds 5 seconds") > 0);
         }
     }
 
@@ -401,7 +401,56 @@ public class SecurityVulnerabilityTest extends AbstractAcceptanceTest {
             xstream.fromXML(xml);
             fail("Thrown " + InputManipulationException.class.getName() + " expected");
         } catch (final InputManipulationException e) {
-            assertTrue("Limit expected in message", e.getMessage().contains("exceeds 5 seconds"));
+            assertTrue("Limit expected in message", e.getMessage().indexOf("exceeds 5 seconds") >= 0);
+        }
+    }
+
+    public void testStackOverflowWithRecursiveHashSet() {
+        final String xml = ""
+            + "<set>\n"
+            + "  <set>\n"
+            + "    <set>\n"
+            + "      <set>\n"
+            + "        <set>\n"
+            + "          <set>\n"
+            + "            <string>a</string>\n"
+            + "          </set>\n"
+            + "          <set>\n"
+            + "            <string>b</string>\n"
+            + "          </set>\n"
+            + "        </set>\n"
+            + "        <set>\n"
+            + "          <string>c</string>\n"
+            + "          <set reference=\"../../../set/set[2]\"/>\n"
+            + "        </set>\n"
+            + "      </set>\n"
+            + "    </set>\n"
+            + "  </set>\n"
+            + "</set>";
+
+        try {
+            xstream.fromXML(xml);
+            fail("Thrown " + InputManipulationException.class.getName() + " expected");
+        } catch (final InputManipulationException e) {
+            assertTrue(e.getMessage().indexOf("Stack Overflow") >= 0);
+        }
+    }
+
+    public void testStackOverflowWithDeeplyNestedStructure() {
+        final StringBuffer xml = new StringBuffer();
+        int i = 0;
+        for( ; i < 10000; ++i) {
+            xml.append("<set>");
+        }
+        for( ; i > 0; --i) {
+            xml.append("</set>");
+        }
+
+        try {
+            xstream.fromXML(xml.toString());
+            fail("Thrown " + InputManipulationException.class.getName() + " expected");
+        } catch (final InputManipulationException e) {
+            assertTrue(e.getMessage().indexOf("Stack Overflow") >= 0);
         }
     }
 }
