@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2005 Joe Walnes.
- * Copyright (C) 2006, 2007, 2014 XStream Committers.
+ * Copyright (C) 2006, 2007, 2014, 2021 XStream Committers.
  * All rights reserved.
  *
  * The software in this package is published under the terms of the BSD
@@ -11,6 +11,8 @@
  */
 package com.thoughtworks.acceptance;
 
+import com.thoughtworks.xstream.converters.reflection.PureJavaReflectionProvider;
+import com.thoughtworks.xstream.converters.reflection.SerializableConverter;
 import com.thoughtworks.xstream.testutil.CallLog;
 
 import java.io.ByteArrayInputStream;
@@ -229,6 +231,72 @@ public class SerializationCallbackOrderTest extends AbstractAcceptanceTest {
         }
     }
 
+    public static class UnserializableBase {
+        protected UnserializableBase() {
+            log.actual("UnserializableBase.UnserializableBase()");
+        }
+    }
+
+    public static class ChildUnserializableBase extends UnserializableBase implements Serializable {
+        /*
+        private ChildUnserializableBase() {
+            log.actual("ChildUnserializableBase.ChildUnserializableBase()");
+        }
+        */
+
+        public ChildUnserializableBase(String s) {
+            log.actual("ChildUnserializableBase.ChildUnserializableBase(String)");
+        }
+
+        private void writeObject(ObjectOutputStream out) throws IOException {
+            log.actual("ChildUnserializableBase.writeObject() start");
+            out.defaultWriteObject();
+            log.actual("ChildUnserializableBase.writeObject() end");
+        }
+
+        private void readObject(ObjectInputStream in) throws IOException, ClassNotFoundException {
+            log.actual("ChildUnserializableBase.readObject() start");
+            in.defaultReadObject();
+            log.actual("ChildUnserializableBase.readObject() end");
+        }
+    }
+
+    public static class ChildUnserializableBaseRR extends ChildUnserializableBase {
+        private ChildUnserializableBaseRR() {
+            super("");
+            log.actual("ChildUnserializableBaseRR.ChildUnserializableBaseRR()");
+        }
+
+        public ChildUnserializableBaseRR(String s) {
+            super(s);
+            log.actual("ChildUnserializableBaseRR.ChildUnserializableBaseRR(String)");
+        }
+
+        private void writeObject(ObjectOutputStream out) throws IOException {
+            log.actual("ChildUnserializableBaseRR.writeObject() start");
+            out.defaultWriteObject();
+            out.writeInt(42);
+            log.actual("ChildUnserializableBaseRR.writeObject() end");
+        }
+
+        private void readObject(ObjectInputStream in) throws IOException, ClassNotFoundException {
+            log.actual("ChildUnserializableBaseRR.readObject() start");
+            in.defaultReadObject();
+            in.readInt();
+            log.actual("ChildUnserializableBaseRR.readObject() end");
+        }
+
+        Object writeReplace() {
+            log.actual("ChildUnserializableBaseRR.writeReplace()");
+            return this;
+        }
+
+        Object readResolve() {
+            log.actual("ChildUnserializableBaseRR.readResolve()");
+            return this;
+        }
+    }
+
     // --- Convenience wrappers around Java Object Serialization
 
     private byte[] javaSerialize(Object object) throws IOException {
@@ -335,6 +403,39 @@ public class SerializationCallbackOrderTest extends AbstractAcceptanceTest {
         log.verify();
     }
 
+    public void testJavaSerializationUnserializableBase() throws IOException {
+        final Serializable object = new ChildUnserializableBase("");
+        log.reset();
+
+        // expectations
+        log.expect("ChildUnserializableBase.writeObject() start");
+        log.expect("ChildUnserializableBase.writeObject() end");
+
+        // execute
+        javaSerialize(object);
+
+        // verify
+        log.verify();
+    }
+
+    public void testJavaSerializationUnserializableBaseRR() throws IOException {
+        final Serializable object = new ChildUnserializableBaseRR("");
+        log.reset();
+
+        // expectations
+        log.expect("ChildUnserializableBaseRR.writeReplace()");
+        log.expect("ChildUnserializableBase.writeObject() start");
+        log.expect("ChildUnserializableBase.writeObject() end");
+        log.expect("ChildUnserializableBaseRR.writeObject() start");
+        log.expect("ChildUnserializableBaseRR.writeObject() end");
+
+        // execute
+        javaSerialize(object);
+
+        // verify
+        log.verify();
+    }
+
     public void testXStreamSerializationOwnPrivateRR() {
         // expectations
         log.expect("PrivateChildOwnRR.writeReplace()");
@@ -424,6 +525,39 @@ public class SerializationCallbackOrderTest extends AbstractAcceptanceTest {
         log.verify();
     }
 
+    public void testXStreamSerializationUnserializableBase() throws IOException {
+        final Serializable object = new ChildUnserializableBase("");
+        log.reset();
+
+        // expectations
+        log.expect("ChildUnserializableBase.writeObject() start");
+        log.expect("ChildUnserializableBase.writeObject() end");
+
+        // execute
+        xstream.toXML(object);
+
+        // verify
+        log.verify();
+    }
+
+    public void testXStreamSerializationUnserializableBaseRR() throws IOException {
+        final Serializable object = new ChildUnserializableBaseRR("");
+        log.reset();
+
+        // expectations
+        log.expect("ChildUnserializableBaseRR.writeReplace()");
+        log.expect("ChildUnserializableBase.writeObject() start");
+        log.expect("ChildUnserializableBase.writeObject() end");
+        log.expect("ChildUnserializableBaseRR.writeObject() start");
+        log.expect("ChildUnserializableBaseRR.writeObject() end");
+
+        // execute
+        xstream.toXML(object);
+
+        // verify
+        log.verify();
+    }
+
     public void testJavaDeserializationOwnPrivateRR() throws IOException, ClassNotFoundException {
         // setup
         byte[] data = javaSerialize(new PrivateChildOwnRR());
@@ -537,6 +671,43 @@ public class SerializationCallbackOrderTest extends AbstractAcceptanceTest {
         log.verify();
     }
 
+    public void testJavaDeserializationUnserializableBase() throws IOException, ClassNotFoundException {
+        // setup
+        byte[] data = javaSerialize(new ChildUnserializableBase(""));
+        log.reset();
+
+        // expectations
+        log.expect("UnserializableBase.UnserializableBase()");
+        log.expect("ChildUnserializableBase.readObject() start");
+        log.expect("ChildUnserializableBase.readObject() end");
+
+        // execute
+        javaDeserialize(data);
+
+        // verify
+        log.verify();
+    }
+
+    public void testJavaDeserializationUnserializableBaseRR() throws IOException, ClassNotFoundException {
+        // setup
+        byte[] data = javaSerialize(new ChildUnserializableBaseRR(""));
+        log.reset();
+
+        // expectations
+        log.expect("UnserializableBase.UnserializableBase()");
+        log.expect("ChildUnserializableBase.readObject() start");
+        log.expect("ChildUnserializableBase.readObject() end");
+        log.expect("ChildUnserializableBaseRR.readObject() start");
+        log.expect("ChildUnserializableBaseRR.readObject() end");
+        log.expect("ChildUnserializableBaseRR.readResolve()");
+
+        // execute
+        javaDeserialize(data);
+
+        // verify
+        log.verify();
+    }
+
     public void testXStreamDeserializationOwnPrivateRR() {
         // setup
         String data = xstream.toXML(new PrivateChildOwnRR());
@@ -650,6 +821,98 @@ public class SerializationCallbackOrderTest extends AbstractAcceptanceTest {
         log.verify();
     }
 
+    public void testXStreamDeserializationUnserializableBaseUnsafe() throws IOException, ClassNotFoundException {
+        // Use Java deserialization for Serializables with unserializable parent, but no readResolve
+
+        // setup
+        String data = xstream.toXML(new ChildUnserializableBase(""));
+        log.reset();
+
+        // expectations
+        // log.expect("UnserializableBase.UnserializableBase()"); // XStream cannot call ctor of parent only
+        log.expect("ChildUnserializableBase.readObject() start");
+        log.expect("ChildUnserializableBase.readObject() end");
+
+        // execute
+        xstream.fromXML(data);
+
+        // verify
+        log.verify();
+    }
+
+    public void testXStreamDeserializationUnserializableBasePure() throws IOException, ClassNotFoundException {
+        // Use Java deserialization for Serializables with unserializable parent, but no readResolve
+
+        // setup
+        xstream.registerConverter(new SerializableConverter(xstream.getMapper(), new PureJavaReflectionProvider(),
+            xstream.getClassLoaderReference()) {
+            public boolean canConvert(Class type) {
+                return type == ChildUnserializableBase.class;
+            }
+        });
+        String data = xstream.toXML(new ChildUnserializableBase(""));
+        log.reset();
+
+        // expectations
+        log.expect("UnserializableBase.UnserializableBase()");
+        log.expect("ChildUnserializableBase.readObject() start");
+        log.expect("ChildUnserializableBase.readObject() end");
+
+        // execute
+        xstream.fromXML(data);
+
+        // verify
+        log.verify();
+    }
+
+    public void testXStreamDeserializationUnserializableBaseRRUnsafe() throws IOException, ClassNotFoundException {
+        // setup
+        String data = xstream.toXML(new ChildUnserializableBaseRR(""));
+        log.reset();
+
+        // expectations
+        // log.expect("UnserializableBase.UnserializableBase()"); // XStream cannot call ctor of parent only
+        log.expect("ChildUnserializableBase.readObject() start");
+        log.expect("ChildUnserializableBase.readObject() end");
+        log.expect("ChildUnserializableBaseRR.readObject() start");
+        log.expect("ChildUnserializableBaseRR.readObject() end");
+        log.expect("ChildUnserializableBaseRR.readResolve()");
+
+        // execute
+        xstream.fromXML(data);
+
+        // verify
+        log.verify();
+    }
+
+    public void testXStreamDeserializationUnserializableBaseRRPure() throws IOException, ClassNotFoundException {
+        // setup
+        xstream.registerConverter(new SerializableConverter(xstream.getMapper(), new PureJavaReflectionProvider(),
+            xstream.getClassLoaderReference()) {
+            public boolean canConvert(Class type) {
+                return type == ChildUnserializableBaseRR.class;
+            }
+        });
+        String data = xstream.toXML(new ChildUnserializableBaseRR(""));
+        log.reset();
+
+        // expectations
+        log.expect("UnserializableBase.UnserializableBase()");
+        log.expect("ChildUnserializableBase.ChildUnserializableBase(String)"); // XStream cannot call ctor of parent only
+        log.expect("ChildUnserializableBaseRR.ChildUnserializableBaseRR()"); // XStream cannot call ctor of parent only
+        log.expect("ChildUnserializableBase.readObject() start");
+        log.expect("ChildUnserializableBase.readObject() end");
+        log.expect("ChildUnserializableBaseRR.readObject() start");
+        log.expect("ChildUnserializableBaseRR.readObject() end");
+        log.expect("ChildUnserializableBaseRR.readResolve()");
+
+        // execute
+        xstream.fromXML(data);
+
+        // verify
+        log.verify();
+    }
+
     public static class ParentNotTransient implements Serializable {
 
         public int somethingNotTransient;
